@@ -19,25 +19,25 @@
   3. This notice may not be removed or altered from any source distribution.
 */
 
-#include "SDL_config.h"
+#include "../sdl3_include_wrapper.h"
+#include "../sdl2_compat.h"
+
 #include "SDL_dynapi.h"
+#define SDL2_PROTO(rc,fn,params) \
+ extern SDL_DECLSPEC rc SDLCALL SDL_##fn##_REAL params ;
+#include "../sdl2_protos.h"
 
 #if SDL_DYNAMIC_API
 
 #define SDL_DYNAMIC_API_ENVVAR "SDL_DYNAMIC_API"
 
-#if defined(__OS2__)
+#if defined(SDL_PLATFORM_OS2)
 #define INCL_DOS
 #define INCL_DOSERRORS
 #include <os2.h>
 #include <dos.h>
 #endif
 
-#include "SDL.h"
-
-/* These headers have system specific definitions, so aren't included above */
-#include "SDL_syswm.h"
-#include "SDL_vulkan.h"
 
 /* This is the version of the dynamic API. This doesn't match the SDL version
    and should not change until there's been a major revamp in API/ABI.
@@ -72,7 +72,7 @@ static void SDL_InitDynamicAPI(void);
         va_list ap;                                                                                          \
         initcall;                                                                                            \
         va_start(ap, fmt);                                                                                   \
-        jump_table.SDL_LogMessageV(category, SDL_LOG_PRIORITY_##prio, fmt, ap);                              \
+        jump_table.SDL_LogMessageV(category, SDL2_LOG_PRIORITY_##prio, fmt, ap);                              \
         va_end(ap);                                                                                          \
     }
 
@@ -138,10 +138,10 @@ static void SDL_InitDynamicAPI(void);
         va_list ap;                                                                                                                       \
         initcall;                                                                                                                         \
         va_start(ap, fmt);                                                                                                                \
-        jump_table.SDL_LogMessageV(SDL_LOG_CATEGORY_APPLICATION, SDL_LOG_PRIORITY_INFO, fmt, ap);                                         \
+        jump_table.SDL_LogMessageV(SDL_LOG_CATEGORY_APPLICATION, SDL2_LOG_PRIORITY_INFO, fmt, ap);                                         \
         va_end(ap);                                                                                                                       \
     }                                                                                                                                     \
-    _static void SDLCALL SDL_LogMessage##name(int category, SDL_LogPriority priority, SDL_PRINTF_FORMAT_STRING const char *fmt, ...)      \
+    _static void SDLCALL SDL_LogMessage##name(int category, SDL2_LogPriority priority, SDL_PRINTF_FORMAT_STRING const char *fmt, ...)      \
     {                                                                                                                                     \
         va_list ap;                                                                                                                       \
         initcall;                                                                                                                         \
@@ -208,7 +208,7 @@ SDL_DYNAPI_VARARGS(static, _DEFAULT, SDL_InitDynamicAPI())
 /* Public API functions to jump into the jump table. */
 #if DISABLE_JUMP_MAGIC
 #define SDL_DYNAPI_PROC(rc, fn, params, args, ret) \
-    rc SDLCALL fn params                           \
+    SDL_DECLSPEC rc SDLCALL fn params                  \
     {                                              \
         ret jump_table.fn args;                    \
     }
@@ -216,7 +216,7 @@ SDL_DYNAPI_VARARGS(static, _DEFAULT, SDL_InitDynamicAPI())
 #include "SDL_dynapi_procs.h"
 #undef SDL_DYNAPI_PROC
 #undef SDL_DYNAPI_PROC_NO_VARARGS
-SDL_DYNAPI_VARARGS(, , )
+SDL_DYNAPI_VARARGS(SDL_DECLSPEC, , )
 #else
 /* !!! FIXME: need the jump magic. */
 #error Write me.
@@ -269,10 +269,10 @@ static void SDLCALL SDL_Log_LOGSDLCALLS(SDL_PRINTF_FORMAT_STRING const char *fmt
     va_list ap;
     SDL_Log_REAL("SDL2CALL SDL_Log");
     va_start(ap, fmt);
-    SDL_LogMessageV_REAL(SDL_LOG_CATEGORY_APPLICATION, SDL_LOG_PRIORITY_INFO, fmt, ap);
+    SDL_LogMessageV_REAL(SDL_LOG_CATEGORY_APPLICATION, SDL2_LOG_PRIORITY_INFO, fmt, ap);
     va_end(ap);
 }
-static void SDLCALL SDL_LogMessage_LOGSDLCALLS(int category, SDL_LogPriority priority, SDL_PRINTF_FORMAT_STRING const char *fmt, ...)
+static void SDLCALL SDL_LogMessage_LOGSDLCALLS(int category, SDL2_LogPriority priority, SDL_PRINTF_FORMAT_STRING const char *fmt, ...)
 {
     va_list ap;
     SDL_Log_REAL("SDL2CALL SDL_LogMessage");
@@ -284,7 +284,7 @@ static void SDLCALL SDL_LogMessage_LOGSDLCALLS(int category, SDL_LogPriority pri
     static void SDLCALL SDL_Log##logname##_LOGSDLCALLS(int category, SDL_PRINTF_FORMAT_STRING const char *fmt, ...) { \
         va_list ap; va_start(ap, fmt); \
         SDL_Log_REAL("SDL2CALL SDL_Log%s", #logname); \
-        SDL_LogMessageV_REAL(category, SDL_LOG_PRIORITY_##prio, fmt, ap); \
+        SDL_LogMessageV_REAL(category, SDL2_LOG_PRIORITY_##prio, fmt, ap); \
         va_end(ap); \
     }
 SDL_DYNAPI_VARARGS_LOGFN_LOGSDLCALLS(Verbose, VERBOSE)
@@ -318,7 +318,7 @@ static Sint32 initialize_jumptable(Uint32 apiver, void *table, Uint32 tablesize)
 #if ENABLE_SDL_CALL_LOGGING
     {
         const char *env = SDL_getenv_REAL("SDL_DYNAPI_LOG_CALLS");
-        const SDL_bool log_calls = (env && SDL_atoi_REAL(env));
+        const bool log_calls = (env && SDL_atoi_REAL(env));
         if (log_calls) {
 #define SDL_DYNAPI_PROC(rc, fn, params, args, ret) jump_table.fn = fn##_LOGSDLCALLS;
 #include "SDL_dynapi_procs.h"
@@ -348,7 +348,7 @@ static Sint32 initialize_jumptable(Uint32 apiver, void *table, Uint32 tablesize)
 /* Here's the exported entry point that fills in the jump table. */
 /*  Use specific types when an "int" might suffice to keep this sane. */
 typedef Sint32 (SDLCALL *SDL_DYNAPI_ENTRYFN)(Uint32 apiver, void *table, Uint32 tablesize);
-extern DECLSPEC Sint32 SDLCALL SDL_DYNAPI_entry(Uint32, void *, Uint32);
+extern SDL_DECLSPEC Sint32 SDLCALL SDL_DYNAPI_entry(Uint32, void *, Uint32);
 
 Sint32 SDL_DYNAPI_entry(Uint32 apiver, void *table, Uint32 tablesize)
 {
@@ -361,7 +361,7 @@ Sint32 SDL_DYNAPI_entry(Uint32 apiver, void *table, Uint32 tablesize)
 
 /* Obviously we can't use SDL_LoadObject() to load SDL.  :)  */
 /* Also obviously, we never close the loaded library. */
-#if defined(WIN32) || defined(_WIN32)
+#if defined(SDL_PLATFORM_WIN32) 
 #ifndef WIN32_LEAN_AND_MEAN
 #define WIN32_LEAN_AND_MEAN 1
 #endif
@@ -379,7 +379,9 @@ static SDL_INLINE void *get_sdlapi_entry(const char *fname, const char *sym)
     return retval;
 }
 
-#elif defined(unix) || defined(__unix__) || defined(__APPLE__) || defined(__HAIKU__) || defined(__QNX__)
+#elif defined(unix) || defined(__unix__) || defined(__APPLE__) || defined(SDL_PLATFORM_HAIKU) || defined(SDL_PLATFORM_QNX)
+#include <stdio.h>
+#include <stdlib.h>
 #include <dlfcn.h>
 static SDL_INLINE void *get_sdlapi_entry(const char *fname, const char *sym)
 {
@@ -394,7 +396,7 @@ static SDL_INLINE void *get_sdlapi_entry(const char *fname, const char *sym)
     return retval;
 }
 
-#elif defined(__OS2__)
+#elif defined(SDL_PLATFORM_OS2)
 static SDL_INLINE void *get_sdlapi_entry(const char *fname, const char *sym)
 {
     HMODULE hmodule;
@@ -416,9 +418,9 @@ static void dynapi_warn(const char *msg)
 {
     const char *caption = "SDL Dynamic API Failure!";
 /* SDL_ShowSimpleMessageBox() is a too heavy for here. */
-#if (defined(WIN32) || defined(_WIN32)) && !defined(__XBOXONE__) && !defined(__XBOXSERIES__)
+#if defined(SDL_PLATFORM_WIN32) && !defined(SDL_PLATFORM_XBOXONE) && !defined(SDL_PLATFORM_XBOXSERIES)
     MessageBoxA(NULL, msg, caption, MB_OK | MB_ICONERROR);
-#elif defined(HAVE_STDIO_H)
+#else
     fprintf(stderr, "\n\n%s\n%s\n\n", caption, msg);
     fflush(stderr);
 #endif
@@ -427,29 +429,34 @@ static void dynapi_warn(const char *msg)
 /* This is not declared in any header, although it is shared between some
     parts of SDL, because we don't want anything calling it without an
     extremely good reason. */
-#ifdef __cplusplus
-extern "C" {
+static SDL_NORETURN void
+DynApiExitProcess(int exitcode)
+{
+#if defined(_WIN32)
+    TerminateProcess(GetCurrentProcess(), exitcode);
+    ExitProcess(exitcode);
+#elif defined(SDL_PLATFORM_OS2)
+    DosExit(EXIT_PROCESS, exitcode);
+#elif defined(SDL_PLATFORM_HAIKU)  /* Haiku has _Exit, but it's not marked noreturn. */
+    _exit(exitcode);
+#else
+    _Exit(exitcode);  /* this (currently) covers everything else. */
 #endif
-extern SDL_NORETURN void SDL_ExitProcess(int exitcode);
-#if defined(__WATCOMC__)
-#pragma aux SDL_ExitProcess aborts;
-#endif
-#ifdef __cplusplus
 }
-#endif
+
 
 static void SDL_InitDynamicAPILocked(void)
 {
     SDL_DYNAPI_ENTRYFN entry = NULL; /* funcs from here by default. */
-    SDL_bool use_internal = SDL_TRUE;
+    bool use_internal = true;
 
-    /* this can't use SDL_getenv_REAL, because it might allocate memory before the app can set their allocator */
-#if defined(WIN32) || defined(_WIN32) || defined(__CYGWIN__)
+    /* this can't use SDL_getenv_REAL, because the SDL3 version behind the scenes allocates memory before the app can set their allocator */
+#if defined(SDL_PLATFORM_WIN32) && !defined(SDL_PLATFORM_XBOXONE) && !defined(SDL_PLATFORM_XBOXSERIES)
     /* We've always used LoadLibraryA for this, so this has never worked with Unicode paths on Windows. Sorry. */
     char envbuf[512];  /* overflows will just report as environment variable being unset, but LoadLibraryA has a MAX_PATH of 260 anyhow, apparently. */
     const DWORD rc = GetEnvironmentVariableA(SDL_DYNAMIC_API_ENVVAR, envbuf, (DWORD) sizeof (envbuf));
     char *libname = ((rc != 0) && (rc < sizeof (envbuf))) ? envbuf : NULL;
-#elif defined(__OS2__)
+#elif defined(SDL_PLATFORM_OS2)
     char * libname;
     if (DosScanEnv(SDL_DYNAMIC_API_ENVVAR, &libname) != NO_ERROR) {
         libname = NULL;
@@ -460,8 +467,9 @@ static void SDL_InitDynamicAPILocked(void)
 
     if (libname) {
         while (*libname && !entry) {
+            // This is evil, but we're not making any permanent changes...
             char *ptr = libname;
-            while (SDL_TRUE) {
+            while (true) {
                 const char ch = *ptr;
                 if ((ch == ',') || (ch == '\0')) {
                     *ptr = '\0';
@@ -485,7 +493,7 @@ static void SDL_InitDynamicAPILocked(void)
             dynapi_warn("Couldn't override SDL library. Using a newer SDL build might help. Please fix or remove the " SDL_DYNAMIC_API_ENVVAR " environment variable. Using the default SDL.");
             /* Just fill in the function pointers from this library, later. */
         } else {
-            use_internal = SDL_FALSE; /* We overrode SDL! Don't use the internal version! */
+            use_internal = false; /* We overrode SDL! Don't use the internal version! */
         }
     }
 
@@ -494,7 +502,7 @@ static void SDL_InitDynamicAPILocked(void)
         if (initialize_jumptable(SDL_DYNAPI_VERSION, &jump_table, sizeof(jump_table)) < 0) {
             /* Now we're screwed. Should definitely abort now. */
             dynapi_warn("Failed to initialize internal SDL dynapi. As this would otherwise crash, we have to abort now.");
-            SDL_ExitProcess(86);
+            DynApiExitProcess(86);
         }
     }
 
@@ -514,7 +522,7 @@ static void SDL_InitDynamicAPI(void)
      *  SDL_CreateThread() would also call this function before building the
      *  new thread).
      */
-    static SDL_bool already_initialized = SDL_FALSE;
+    static bool already_initialized = false;
 
     /* SDL_AtomicLock calls SDL mutex functions to emulate if
        SDL_ATOMIC_DISABLED, which we can't do here, so in such a
@@ -526,7 +534,7 @@ static void SDL_InitDynamicAPI(void)
 
     if (!already_initialized) {
         SDL_InitDynamicAPILocked();
-        already_initialized = SDL_TRUE;
+        already_initialized = true;
     }
 
     #ifndef SDL_ATOMIC_DISABLED
@@ -535,5 +543,3 @@ static void SDL_InitDynamicAPI(void)
 }
 
 #endif /* SDL_DYNAMIC_API */
-
-/* vi: set ts=4 sw=4 expandtab: */
